============
Scikit oTree
============

.. image:: https://travis-ci.org/leliel12/scikit-otree.svg?branch=master
    :target: https://travis-ci.org/leliel12/scikit-otree
    :alt: Build-Status

.. image:: https://badge.fury.io/py/scikit-otree.svg
    :target: https://badge.fury.io/py/scikit-otree

.. image:: https://img.shields.io/badge/License-MIT-blue.svg
   :target: https://opensource.org/licenses/MIT
   :alt: License

.. image:: https://img.shields.io/badge/python-3.5-blue.svg
   :target: https://badge.fury.io/py/scikit-otree
   :alt: Python 3.5

.. image:: https://img.shields.io/badge/python-3.6-blue.svg
   :target: https://badge.fury.io/py/scikit-otree
   :alt: Python 3.6


`oTree <http://www.otree.org/>`_ integration to the scientific Python Stack

Based on:

    Chen, D. L., Schonger, M., & Wickens, C. (2016).
    oTree-An open-source platform for laboratory, online, and field experiments.
    Journal of Behavioral and Experimental Finance, 9, 88-97.


Quickstart
----------

Typical setup
~~~~~~~~~~~~~

.. code-block:: bash

    $ pip install --upgrade scikit-otree


Support
-------

-   **Full Documentation and Tutorial:**
    `tutorial.ipynb <https://github.com/leliel12/scikit-otree/blob/master/tutorial.ipynb>`_
-   **Contact:** jbc.develop@gmail.com
-   **Issues:** If you have issues please report them as a issue
    here: https://github.com/leliel12/scikit-otree/issues



Test
----

Clone or download this project and inside the project folder run:

.. code-block:: bash

    $ pip install tox
    $ tox
